#!/bin/env python3
from pygments.style import Style
from pygments.token import Token
from pygments.formatters import HtmlFormatter

class NewStyle(Style):
    default_style = ""

    green = "#006600"
    night_blue =  "#204A87"
    purple = "#68175A"
    dark_red = "#880000"
    grey = "#586178"
    black = "#000000"

    styles = {
        Token.Whitespace: "",
        Token.Text: "",
        Token.Keyword: "bold",
        Token.Comment: grey,
        Token.String: night_blue,
        Token.String.Escape: black,
        Token.String.Symbol: night_blue,
        Token.Pitch: "", #"#911520",
        Token.Name.Constant: night_blue, # Scheme #t and #f
        Token.Number: night_blue, # includes durations
        # A bare 11 is not distinguishable from a number, so we highlight
        # the same.
        Token.ChordModifier: night_blue,
        Token.Name.Lvalue: "", #black,
        Token.Name.BackslashReference: dark_red,
        Token.Name.Builtin.MusicCommand: black,
        Token.Name.Builtin.PaperVariable: black,
        Token.Name.Builtin.HeaderVariable: black,
        Token.Name.Builtin.MusicFunction: black,
        Token.Name.Builtin.Clef: "",
        Token.Name.Builtin.Scale: black,
        Token.Name.Builtin.RepeatType: black,
        Token.Name.Builtin.Dynamic: black,
        Token.Name.Builtin.Articulation: black,
        Token.Name.Builtin.SchemeFunction: black,
        Token.Name.Builtin.SchemeBuiltin: "bold",
        Token.Name.Builtin.MarkupCommand: black,
        Token.Name.Builtin.Context: black,
        Token.Name.Builtin.ContextProperty: black,
        Token.Name.Builtin.Grob: "italic #000000",
        Token.Name.Builtin.GrobProperty: "italic #000000",
        Token.Name.Builtin.Translator: black,
    }

with open("lilypond-highlighting.css", "w") as file:
    file.write(HtmlFormatter(style=NewStyle).get_style_defs(".highlight"))
